@@ -12,19 +12,16 @@ class TestPreprocessing(unittest.TestCase):
         cls.targets = [2, 3, 4]
 
     def test_from_training(self):
-        scaler = StandardScaler.from_training_data(self.structures,
-                                                   self.targets, is_intensive=False)
+        scaler = StandardScaler.from_training_data(self.structures, self.targets, is_intensive=False)
         self.assertEqual(scaler.mean, 1)
         self.assertEqual(scaler.std, 1)
 
     def test_transform_inverse_transform(self):
-        scaler = StandardScaler.from_training_data(self.structures,
-                                                   self.targets, is_intensive=False)
+        scaler = StandardScaler.from_training_data(self.structures, self.targets, is_intensive=False)
         transformed_target = scaler.transform(100, 1)
         orig_target = scaler.inverse_transform(transformed_target, 1)
         self.assertAlmostEqual(100, orig_target)
-        scaler = StandardScaler.from_training_data(self.structures,
-                                                   self.targets, is_intensive=True)
+        scaler = StandardScaler.from_training_data(self.structures, self.targets, is_intensive=True)
         transformed_target = scaler.transform(100, 1)
         orig_target = scaler.inverse_transform(transformed_target, 1)
         self.assertAlmostEqual(100, orig_target)
@@ -32,4 +29,3 @@ class TestPreprocessing(unittest.TestCase):
 
 if __name__ == "__main__":
     unittest.main()
-
